exceptiontools.TonalHarmonyError
================================

.. inheritance-diagram:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
